// Persistence Of Vision raytracer version 3.1 sample file.

#declare torusx = torus { 9.5, 0.5 sturm }
#declare torus0 = torus { 9.376883, 0.500000 sturm }
#declare torus1 = torus { 9.010565, 0.500000 sturm }
#declare torus2 = torus { 8.410065, 0.500000 sturm }
#declare torus3 = torus { 7.590170, 0.500000 sturm }
#declare torus4 = torus { 6.571068, 0.500000 sturm }
#declare torus5 = torus { 5.377853, 0.500000 sturm }
#declare torus6 = torus { 4.039905, 0.500000 sturm }
#declare torus7 = torus { 2.590170, 0.500000 sturm }
#declare torus8 = torus { 1.064345, 0.500000 sturm }
#declare torus9 = torus { 9.500000, 0.200000 sturm }
