// Persistence Of Vision raytracer version 3.1 sample file.

#declare light1c = color red 0.1 green 0.1 blue 0.1;
#declare light2c = color red 0.2 green 0.2 blue 0.2;
#declare light3c = color red 0.3 green 0.3 blue 0.3;
#declare light4c = color red 0.4 green 0.4 blue 0.4;
#declare light5c = color red 0.5 green 0.5 blue 0.5;

#declare light1 = light_source { <0.0, 0.0, 0.0> color light1c }
#declare light2 = light_source { <0.0, 0.0, 0.0> color light2c }
#declare light3 = light_source { <0.0, 0.0, 0.0> color light3c }
#declare light4 = light_source { <0.0, 0.0, 0.0> color light4c }
#declare light5 = light_source { <0.0, 0.0, 0.0> color light5c }

