//  Persistence of Vision Raytracer Version 3.1


// Use this file before '#including' any others to turn on a display of
// the names of the .inc files as they are loaded.
#declare View_POV_Include_Stack = 1;
